# abvelocity

A library to increase experimentation velocity.
The main current supported tooling is called "Multi-Experiment Analysis (MEA)".

MEA allows us to analyze multiple concurrent orthogonal experiments.


See [What is MEA?](./docs/docs/content/2-what-is-mea.md)

See [Run MEA (Generic Version)](./docs/docs/content/4-run-mea-generic.md)

See [MEA Report](./docs/docs/content/5-mea-report.md)


# Important Notice: Early Development Phase

Please be aware that this library is currently in its **initial development and testing phase**. It is **not yet ready for production use** and comes with **absolutely no warranty**. Use at your own discretion.
